@@ -41,6 +41,7 @@ from .routing_api import RoutingApi
 from .scim_api import SCIMApi
 from .scripts_api import ScriptsApi
 from .search_api import SearchApi
+from .speech_text_analytics_api import SpeechTextAnalyticsApi
 from .stations_api import StationsApi
 from .suggest_api import SuggestApi
 from .telephony_api import TelephonyApi
@@ -49,6 +50,7 @@ from .textbots_api import TextbotsApi
 from .tokens_api import TokensApi
 from .uploads_api import UploadsApi
 from .usage_api import UsageApi
+from .user_development_api import UserDevelopmentApi
 from .user_recordings_api import UserRecordingsApi
 from .users_api import UsersApi
 from .utilities_api import UtilitiesApi
